Store class

Properties

hashCode → int
The hash code for this object.
no setterinherited
localTextureParam → TRTCRenderParams
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textureUserIdMap → Map<int, String>
no setter
userRenderParamsMap → Map<String, TRTCRenderParams>
no setter

Methods

clean() → void
deleteUser(String userId) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLocalTextureParam(TRTCRenderParams param) → void
setTextureUserIdMap(int textureId, String userId) → void
setUserRenderParamsMap(String userId, TRTCRenderParams param) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

sharedInstance() → Store