TRTCScreenCaptureProperty class

Advanced control parameters for screen sharing

This parameter is used in the screen sharing related interface TRTCCloud.selectScreenCaptureTarget to set a series of advanced control parameters when specifying the sharing target.

For example: whether to collect the mouse, whether to collect the sub-window, whether to draw a border around the shared target, etc.

Constructors

TRTCScreenCaptureProperty({bool enableCaptureMouse = true, bool enableHighLight = true, bool enableHighPerformance = true, int highLightColor = 0x000000, int highLightWidth = 0, bool enableCaptureChildWindow = false})
TRTCScreenCaptureProperty.fromJson(Map<String, dynamic> json)
Parse the corresponding structure from Json
factory

Properties

enableCaptureChildWindow ↔ bool
Whether to collect sub-windows when collecting windows (the sub-window and the window being collected need to have Owner or Popup attributes), the default is false.
getter/setter pair
enableCaptureMouse ↔ bool
Whether to collect the mouse while collecting the target content, the default is true.
getter/setter pair
enableHighLight ↔ bool
Whether to highlight the window being shared (draw a border around the shared target), the default is true.
getter/setter pair
enableHighPerformance ↔ bool
Whether to enable high-performance mode (will only take effect when sharing the screen), the default is true.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highLightColor ↔ int
Specify the color of the highlight border in RGB format. When 0 is passed in, the default color is used. The default color is #FFE640.
getter/setter pair
highLightWidth ↔ int
Specify the width of the highlight border. When 0 is passed in, the default stroke width is used. The default width is 5px, and the maximum value you can set is 50.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert the current object to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited